@@ -22,17 +22,9 @@ class ComponentSpecificParametersEnum:
     DOCKSTREAM_ENVPATH = "environment_path"
     DOCKSTREAM_DEBUG = "debug"
 
-    # AZGARD
-    AZGARD_CONFPATH = "configuration_path"
-    AZGARD_EXECUTORSCRIPTPATH = "executor_script_path"
-    AZGARD_ENVPATH = "environment_path"
-    AZGARD_VALUES_KEY = "values_key"
-    AZGARD_DEBUG = "debug"
-
     # ICOLOS
     ICOLOS_CONFPATH = "configuration_path"
-    ICOLOS_EXECUTORSCRIPTPATH = "executor_script_path"
-    ICOLOS_ENVPATH = "environment_path"
+    ICOLOS_EXECUTOR_PATH = "executor_path"
     ICOLOS_VALUES_KEY = "values_key"
     ICOLOS_DEBUG = "debug"
     #######################
@@ -44,3 +36,8 @@ class ComponentSpecificParametersEnum:
 
     SMILES = "smiles"
     MODEL_PATH = "model_path"
+
+    #######################
+    ARTIFACT = "artifact"
+
+    AIZYNTH_CONFIG_FILE_PATH = "aizynth_config_file_path"
