@@ -1,5 +1,7 @@
+from dataclasses import dataclass
 
 
+@dataclass(frozen=True)
 class ScoringFunctionComponentNameEnum:
     PARALLEL_ROCS_SIMILARITY = "parallel_rocs_similarity"
     SELECTIVITY = "selectivity"
@@ -40,19 +42,10 @@ class ScoringFunctionComponentNameEnum:
     LINKER_RATIO_ROTATABLE_BONDS = "linker_ratio_rotatable_bonds"
 
     #NOTE: components below are AZ specific
-    AZ_LOGD74 = "az_logd74"
-    HLM_CLINT = "hlm_clint"
-    RH_CLINT = "rh_clint"
-    HH_CLINT = "hh_clint"
-    SOLUBILITY_DD = "solubilityDD"
-    CACO2_INTR = "caco2_intr"
-    CACO2_EFFLUX = "caco2_efflux"
-    HERG = "clab_herg"
     SA_SCORE = "sa_score"
     AZDOCK = "azdock"
     DOCKSTREAM = "dockstream"
     ICOLOS = "icolos"
-    AZGARD = "azgard"
     AZ_LOGD74_PIP = "azlogd74"
     CACO2_INTR_PIP = "caco2-intrinsic-papp"
     CACO2_EFFLUX_PIP = "caco2-efflux"
@@ -66,11 +59,5 @@ class ScoringFunctionComponentNameEnum:
     CLAB_TOP_20 = "clab_top_20"
     RA_SCORE = "rascore"
     AIZYNTH = "aizynth"
-
-    def __getattr__(self, name):
-        if name in self:
-            return name
-        raise AttributeError
-
-    def __setattr__(self, key, value):
-        raise ValueError("Do not assign value to a ScoringFunctionComponentNameEnum field.")
+    QPTUNA_PIP_MODEL = "optuna-multi"
+    THP1_CYTOTOXICITY = "thp1-class"
