@@ -7,16 +7,13 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     JaccardDistance, CustomAlerts, QedScore, MatchingSubstructure, \
     RocsSimilarity, ParallelRocsSimilarity, PredictivePropertyComponent, SelectivityComponent, \
     SASComponent, MolWeight, PSA, RotatableBonds, HBD_Lipinski, HBA_Lipinski, \
-    NumRings, AZlogD74, HLMClint, SlogP, \
-    RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20, GraphLength, \
-    NumberOfStereoCenters, \
+    NumRings, SlogP, AZdock, RatPKPiP, PiPLogPredictionComponent, PiPPredictionComponent, \
+    QptunaPiPModelComponent, GraphLength, NumberOfStereoCenters, \
     LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength, LinkerNumRings, LinkerNumAliphaticRings, \
     LinkerNumAromaticRings, LinkerNumSPAtoms, LinkerNumSP2Atoms, LinkerNumSP3Atoms, LinkerNumHBA, \
     LinkerNumHBD, LinkerMolWeight, LinkerRatioRotatableBonds, DockStream, BuildingBlockAvailabilityComponent, \
     NumAromaticRings, NumAliphaticRings
-from reinvent_scoring.scoring.score_components.console_invoked import AZgard
-from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
-from reinvent_scoring.scoring.score_components.pip.pip_prediction_component import PiPPredictionComponent
+from reinvent_scoring.scoring.score_components.console_invoked import Icolos
 
 
 class ScoreComponentFactory:
@@ -46,14 +43,6 @@ class ScoreComponentFactory:
             enum.SLOGP: SlogP,
             enum.NUMBER_OF_STEREO_CENTERS: NumberOfStereoCenters,
             enum.PARALLEL_ROCS_SIMILARITY: ParallelRocsSimilarity,
-            enum.AZ_LOGD74: AZlogD74,
-            enum.HLM_CLINT: HLMClint,
-            enum.RH_CLINT: RHClint,
-            enum.HH_CLINT: HHClint,
-            enum.SOLUBILITY_DD: SolubilityDD,
-            enum.HERG: HERG,
-            enum.CACO2_INTR: CACO2Intrinsic,
-            enum.CACO2_EFFLUX: CACO2Efflux,
             enum.SELECTIVITY: SelectivityComponent,
             enum.SA_SCORE: SASComponent,
             enum.AZDOCK: AZdock,
@@ -66,9 +55,10 @@ class ScoreComponentFactory:
             enum.SOLUBILITY_DD_PIP: PiPLogPredictionComponent,
             enum.HERG_PIP: PiPPredictionComponent,
             enum.RAT_PK_PIP: RatPKPiP,
-            enum.CLAB_TOP_20: Top20,
             enum.RA_SCORE: PiPPredictionComponent,
             enum.KPUU_PIP: PiPLogPredictionComponent,
+            enum.QPTUNA_PIP_MODEL: QptunaPiPModelComponent,
+            enum.THP1_CYTOTOXICITY: PiPPredictionComponent,
             enum.LINKER_GRAPH_LENGTH: LinkerGraphLength,
             enum.LINKER_EFFECTIVE_LENGTH: LinkerEffectiveLength,
             enum.LINKER_LENGTH_RATIO: LinkerLengthRatio,
@@ -83,7 +73,7 @@ class ScoreComponentFactory:
             enum.LINKER_MOL_WEIGHT: LinkerMolWeight,
             enum.LINKER_RATIO_ROTATABLE_BONDS: LinkerRatioRotatableBonds,
             enum.DOCKSTREAM: DockStream,
-            enum.AZGARD: AZgard,
+            enum.ICOLOS: Icolos,
             enum.AIZYNTH: BuildingBlockAvailabilityComponent
         }
         return component_map
